/***
 * Juliac
 * Copyright (C) 2010-2013 Inria, Univ. Lille 1
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: fractal@ow2.org
 *
 * Author: Lionel Seinturier
 */

package org.objectweb.fractal.juliac.mind;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.objectweb.fractal.adl.ADLException;
import org.objectweb.fractal.adl.Definition;
import org.ow2.mind.Launcher;
import org.ow2.mind.adl.graph.ComponentGraph;

/**
 * A wrapper for the MIND toolchain launcher.
 * 
 * @author Lionel Seinturier <Lionel.Seinturier@univ-lille1.fr>
 * @since 2.2.4
 */
public class MindLauncher extends Launcher {

	public MindLauncher(String... args) throws Exception {
		super(args);
	}

	@Override
	protected void compile(
		String adlName, String execName, List<Object> result )
	throws ADLException, InterruptedException {
		
		Map<Object,Object> contextMap =
			new HashMap<Object,Object>(compilerContext);
		
		if (execName != null) {
			contextMap.put(EXEC_NAME,execName);
		}

		adlName = processContext(targetDescriptor,adlName,contextMap);
		Definition adlDef = adlLoader.load(adlName,contextMap);
		adlDef = astTransformer.toStringTemplateAST(adlDef);
		graph = graphInstantiator.instantiate(adlDef,contextMap);
	}
	
	public ComponentGraph getComponentGraph() {
		return graph;
	}
	private ComponentGraph graph;
}
